/* override libadwaita style of heavily padded columnviews */

listview cell {
  padding: 2px 2px;
}

/* Give textviews a border */

textview {
  border: 1px solid;
  border-radius: 2%;
  border-color: @borders;
}
